This module contains types necessary for processing vote extensions.
Modules
- bridge_
pool_ roots - Vote extension types for adding a signature of the bridge pool merkle root to be added to storage. This will be used to generate bridge pool inclusion proofs for Ethereum.
- ethereum_
events - Contains types necessary for processing Ethereum events in vote extensions.
- ethereum_
tx_ data_ variants - All the variants of
EthereumTxData, stored in a module. - validator_
set_ update - Contains types necessary for processing validator set updates in vote extensions.
Structs
- Vote
Extension - This type represents the data we pass to the extension of a vote at the PreCommit phase of Tendermint.
Enums
- Ethereum
TxData - Data associated with Ethereum protocol transactions.
Traits
- Ethereum
TxData Variants - All the variants of
EthereumTxData, stored in a trait.